@@ -8,7 +8,7 @@ from .calculation import calculate_impacts, get_default_hazard_model, get_defaul
 from .financial_model import FinancialModelBase
 from .hazard_model import HazardModel
 from .impact_distrib import ImpactDistrib, ImpactType
-from .vulnerability_model import VulnerabilityModelBase
+from .vulnerability_model import VulnerabilityModelAcuteBase
 
 
 class Aggregator(ABC):
@@ -19,14 +19,14 @@ class Aggregator(ABC):
 
 class DefaultAggregator(Aggregator):
     def get_aggregation_keys(self, asset: Asset, impact: ImpactDistrib) -> List:
-        return [(impact.event_type.__name__), ("root")]
+        return [(impact.hazard_type.__name__), ("root")]
 
 
 class LossModel:
     def __init__(
         self,
         hazard_model: Optional[HazardModel] = None,
-        vulnerability_models: Optional[Dict[type, Sequence[VulnerabilityModelBase]]] = None,
+        vulnerability_models: Optional[Dict[type, Sequence[VulnerabilityModelAcuteBase]]] = None,
     ):
         self.hazard_model = get_default_hazard_model() if hazard_model is None else hazard_model
         self.vulnerability_models = (
@@ -57,7 +57,7 @@ class LossModel:
 
         rg = np.random.Generator(np.random.MT19937(seed=111))
 
-        for asset, result in results.items():
+        for (asset, hazard_type), result in results.items():
             # look up keys for results
             impact = result.impact
             keys = aggregator.get_aggregation_keys(asset, impact)
