@@ -7,14 +7,14 @@ import numpy as np
 
 import physrisk.data.static.vulnerability
 
-from ..data_objects.vulnerability_curve import VulnerabilityCurves
+from ..api.v1.common import VulnerabilityCurves
 from .assets import Asset
 from .curve import ExceedanceCurve
 from .hazard_event_distrib import HazardEventDistrib
-from .hazard_model import EventDataRequest, EventDataResponse
-from .impact_curve import ImpactCurve
+from .hazard_model import HazardDataRequest, HazardDataResponse, HazardEventDataResponse
 from .impact_distrib import ImpactDistrib
 from .vulnerability_distrib import VulnerabilityDistrib
+from .vulnerability_matrix_provider import VulnMatrixProvider
 
 PLUGINS = dict()
 
@@ -49,29 +49,36 @@ def get_vulnerability_curves_from_resource(id: str) -> VulnerabilityCurves:
 
 
 class VulnerabilityModelBase(ABC):
-    """Models generate the VulnerabilityDistrib and HazardEventDistrib of an
-    Asset.
-    """
-
-    def __init__(self, model: str, event_type: type, year: int, scenario: str):
+    def __init__(self, model: str, hazard_type: type):
         self.model = model
-        self.event_type = event_type
-        self.year = year
-        self.scenario = scenario
+        self.hazard_type = hazard_type
         self._event_types: List[type] = []
         self._asset_types: List[type] = []
 
     @abstractmethod
-    def get_event_data_requests(
+    def get_data_requests(
         self, asset: Asset, *, scenario: str, year: int
-    ) -> Union[EventDataRequest, Iterable[EventDataRequest]]:
+    ) -> Union[HazardDataRequest, Iterable[HazardDataRequest]]:
         """Provide the one or more hazard event data requests required in order to calculate
         the VulnerabilityDistrib and HazardEventDistrib for the asset."""
         ...
 
+    @abstractmethod
+    def get_impact(self, asset: Asset, event_data: Iterable[HazardDataResponse]) -> ImpactDistrib:
+        ...
+
+
+class VulnerabilityModelAcuteBase(VulnerabilityModelBase):
+    """Models generate the VulnerabilityDistrib and HazardEventDistrib of an
+    Asset.
+    """
+
+    def __init__(self, model: str, hazard_type: type):
+        super().__init__(model, hazard_type)
+
     @abstractmethod
     def get_distributions(
-        self, asset: Asset, event_data_responses: Iterable[EventDataResponse]
+        self, asset: Asset, event_data_responses: Iterable[HazardDataResponse]
     ) -> Tuple[VulnerabilityDistrib, HazardEventDistrib]:
         """Return distributions for asset: VulnerabilityDistrib and HazardEventDistrib.
         The hazard event data is used to do this.
@@ -82,8 +89,12 @@ class VulnerabilityModelBase(ABC):
         """
         ...
 
-    def get_impact(
-        self, asset: Asset, event_data_responses: Iterable[EventDataResponse]
+    def get_impact(self, asset: Asset, event_data_responses: Iterable[HazardDataResponse]):
+        impact, _, _ = self.get_impact_details(asset, event_data_responses)
+        return impact
+
+    def get_impact_details(
+        self, asset: Asset, event_data_responses: Iterable[HazardDataResponse]
     ) -> Tuple[ImpactDistrib, VulnerabilityDistrib, HazardEventDistrib]:
         """Return impact distribution along with vulnerability and hazard event distributions used to infer this.
 
@@ -100,52 +111,54 @@ class VulnerabilityModelBase(ABC):
         )
 
     def _check_event_type(self):
-        if self.event_type not in self._event_types:
-            raise NotImplementedError(f"model does not support events of type {self.event_type.__name__}")
+        if self.hazard_type not in self._event_types:
+            raise NotImplementedError(f"model does not support events of type {self.hazard_type.__name__}")
 
 
-class VulnerabilityModel(VulnerabilityModelBase):
+class VulnerabilityModel(VulnerabilityModelAcuteBase):
     """A vulnerability model that requires only specification of distributions of impacts for given intensities,
     by implementing get_impact_curve."""
 
-    def __init__(self, *, model: str = "", event_type: type, impact_bin_edges):
-        self.event_type = event_type
+    def __init__(self, *, model: str = "", hazard_type: type, impact_bin_edges):
+        self.hazard_type = hazard_type
         self.model = model
         self.impact_bin_edges = impact_bin_edges
 
-    def get_event_data_requests(
+    def get_data_requests(
         self, asset: Asset, *, scenario: str, year: int
-    ) -> Union[EventDataRequest, Iterable[EventDataRequest]]:
-        return EventDataRequest(
-            self.event_type, asset.longitude, asset.latitude, scenario=scenario, year=year, model=self.model
+    ) -> Union[HazardDataRequest, Iterable[HazardDataRequest]]:
+        return HazardDataRequest(
+            self.hazard_type, asset.longitude, asset.latitude, scenario=scenario, year=year, model=self.model
         )
 
     def get_distributions(
-        self, asset: Asset, event_data_responses: Iterable[EventDataResponse]
+        self, asset: Asset, event_data_responses: Iterable[HazardDataResponse]
     ) -> Tuple[VulnerabilityDistrib, HazardEventDistrib]:
 
         (event_data,) = event_data_responses
+        assert isinstance(event_data, HazardEventDataResponse)
+
         intensity_curve = ExceedanceCurve(1.0 / event_data.return_periods, event_data.intensities)
         intensity_bin_edges, probs = intensity_curve.get_probability_bins()
         intensity_bin_centres = (intensity_bin_edges[1:] + intensity_bin_edges[:-1]) / 2
 
         vul = VulnerabilityDistrib(
-            self.event_type,
+            self.hazard_type,
             intensity_bin_edges,
             self.impact_bin_edges,
             self.get_impact_curve(intensity_bin_centres, asset).to_prob_matrix(self.impact_bin_edges),
         )
 
-        event = HazardEventDistrib(self.event_type, intensity_bin_edges, probs)
+        event = HazardEventDistrib(self.hazard_type, intensity_bin_edges, probs)
         return vul, event
 
     @abstractmethod
-    def get_impact_curve(self, intensities, asset) -> ImpactCurve:
+    def get_impact_curve(self, intensities, asset) -> VulnMatrixProvider:
         """Get the impact curves for the intensities specified."""
         ...
 
 
-class DeterministicVulnerabilityModel(VulnerabilityModelBase):
+class DeterministicVulnerabilityModel(VulnerabilityModelAcuteBase):
     """A vulnerability model that requires only specification of a damage/disruption curve.
     This simple model contains no uncertainty around damage/disruption."""
 
@@ -155,18 +168,20 @@ class DeterministicVulnerabilityModel(VulnerabilityModelBase):
         self.impacts = impacts
         self.model = model
 
-    def get_event_data_requests(
+    def get_data_requests(
         self, asset: Asset, *, scenario: str, year: int
-    ) -> Union[EventDataRequest, Iterable[EventDataRequest]]:
-        return EventDataRequest(
+    ) -> Union[HazardDataRequest, Iterable[HazardDataRequest]]:
+        return HazardDataRequest(
             self.event_type, asset.longitude, asset.latitude, scenario=scenario, year=year, model=self.model
         )
 
     def get_distributions(
-        self, asset: Asset, event_data_responses: Iterable[EventDataResponse]
+        self, asset: Asset, event_data_responses: Iterable[HazardDataResponse]
     ) -> Tuple[VulnerabilityDistrib, HazardEventDistrib]:
 
         (event_data,) = event_data_responses
+        assert isinstance(event_data, HazardEventDataResponse)
+
         intensity_curve = ExceedanceCurve(1.0 / event_data.return_periods, event_data.intensities)
         intensity_bin_edges, probs = intensity_curve.get_probability_bins()
 
